Skip to contents

Returns a list of the working database and all loaded datasets.

Usage

gdataset.ls(dataframe = FALSE)

Arguments

dataframe

If FALSE, return character vector; if TRUE, return data frame

Value

Character vector of paths or data frame with detailed information

Examples


dataset_path <- gdataset.example_path()
gdataset.load(dataset_path)
gdataset.ls()
#> [1] "/tmp/RtmpLRFtNu/trackdb/test"              
#> [2] "/tmp/RtmpLRFtNu/misha_dataset_1b2e4bc00a7c"
gdataset.unload(dataset_path)