Returns information about a misha genome database including format, number of chromosomes, total genome size, and whether it uses the indexed format.
Value
A list with database information:
path- Full path to the databaseis_db- TRUE if this is a valid misha databaseformat- "indexed" or "per-chromosome"num_chromosomes- Number of chromosomes/contigsgenome_size- Total length of genome in baseschromosomes- Data frame with chromosome names and sizes