Changes current working directory in Genomic Database.
Details
This function changes the current working directory in Genomic Database (not to be confused with shell's current working directory). The list of database objects - tracks, intervals, track variables - is rescanned recursively under 'dir'. Object names are updated with the respect to the new current working directory. Example: a track named 'subdir.dense' will be referred as 'dense' once current working directory is set to 'subdir'. All virtual tracks are removed.
Examples
gdb.init_examples()
gdir.cd("subdir")
gtrack.ls()
#> [1] "dense_track2"
gdir.cd("..")
gtrack.ls()
#> [1] "array_track" "dense_track" "rects_track"
#> [4] "sparse_track" "subdir.dense_track2"