Creates a new directory in Genomic Database.
Usage
gdir.create(dir = NULL, showWarnings = TRUE, mode = "0777")
Arguments
- dir
directory path
- showWarnings
see 'dir.create'
- mode
see 'dir.create'
Details
This function creates a new directory in Genomic Database. Creates only the
last element in the specified path.
Note
A new directory cannot be created within an existing track directory.