gintervals.attr.get: Returns value of an interval set attribute

View source: R/intervals-attr.R

gintervals.attr.getR Documentation

Returns value of an interval set attribute

Description

Returns value of an interval set attribute.

Usage

gintervals.attr.get(intervals.set = NULL, attr = NULL)

Arguments

intervals.set

interval set name

attr

attribute name

Details

This function returns the value of an interval set attribute. If the attribute does not exist an empty string is returned.

Value

Interval set attribute value (character string).

See Also

gintervals.attr.set, gintervals.attr.export, gintervals.attr.import

Examples



gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
gintervals.attr.set("annotations", "test_attr", "")


misha documentation built on Aug. 24, 2026, 5:14 p.m.