gintervals.attr.set: Assigns value to an interval set attribute

View source: R/intervals-attr.R

gintervals.attr.setR Documentation

Assigns value to an interval set attribute

Description

Assigns value to an interval set attribute.

Usage

gintervals.attr.set(intervals.set = NULL, attr = NULL, value = NULL)

Arguments

intervals.set

interval set name

attr

attribute name

value

value (character string)

Details

This function creates an interval set attribute and assigns 'value' to it. If the attribute already exists its value is overwritten.

If 'value' is an empty string the attribute is removed.

Value

None.

See Also

gintervals.attr.get, gintervals.attr.export, gintervals.attr.import

Examples



gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
gintervals.attr.set("annotations", "test_attr", "")


misha documentation built on Aug. 24, 2026, 5:14 p.m.