Returns the path on disk of an interval set.
Details
This function returns the actual file system path where an interval set is stored. The function works with a single interval set name or a vector of names.
Examples
gdb.init_examples()
gintervals.path("annotations")
#> [1] "/tmp/RtmpMHZs6a/trackdb/test/tracks/annotations.interv"
gintervals.path(c("annotations", "coding"))
#> [1] "/tmp/RtmpMHZs6a/trackdb/test/tracks/annotations.interv"
#> [2] "/tmp/RtmpMHZs6a/trackdb/test/tracks/coding.interv"