Deletes a named intervals set.
Arguments
- intervals.set
name of an intervals set
- force
if 'TRUE', suppresses user confirmation of a named intervals set removal
- db
optional database path. When multiple databases are connected, this specifies which database to delete the intervals set from. If NULL (the default), the intervals set is deleted from the working database (GROOT).
Details
This function deletes a named intervals set from the Genomic Database. By default 'gintervals.rm' requires the user to interactively confirm the deletion. Set 'force' to 'TRUE' to suppress the user prompt.
Examples
gdb.init_examples()
intervs <- gintervals(c(1, 2))
gintervals.save("testintervs", intervs)
gintervals.ls()
#> [1] "annotations" "testintervs"
gintervals.rm("testintervs", force = TRUE)
gintervals.ls()
#> [1] "annotations"