| gsynth.save | R Documentation |
Saves a trained Markov model in the cross-platform .gsm format, which consists of a metadata YAML file and raw binary arrays for counts and CDFs. The .gsm format can be stored as a directory (default) or a ZIP archive.
gsynth.save(model, file, compress = FALSE)
model |
A gsynth.model object from |
file |
Path to save the model (directory or .zip file) |
compress |
Logical. If |
Invisibly returns the file path.
gsynth.load, gsynth.train,
gsynth.convert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.