Returns the path of the database or dataset containing a track.
Details
When datasets are loaded, tracks can come from either the working database or from loaded datasets. This function returns the source path for each track.
Examples
gdb.init_examples()
gtrack.dataset("dense_track")
#> [1] "/tmp/RtmpMHZs6a/trackdb/test"