gvtrack.clear: Deletes all virtual tracks

View source: R/vtrack.R

gvtrack.clearR Documentation

Deletes all virtual tracks

Description

Deletes all virtual tracks of the current working directory.

Usage

gvtrack.clear()

Details

This function removes every virtual track defined for the current working directory in one call. After it returns gvtrack.ls reports no virtual tracks. It is a convenient way to reset virtual-track state between analyses. Use gvtrack.rm to remove a single virtual track.

Value

None.

See Also

gvtrack.rm, gvtrack.ls, gvtrack.create

Examples



gdb.init_examples()
gvtrack.create("vtrack1", "dense_track", "max")
gvtrack.create("vtrack2", "dense_track", "avg")
gvtrack.ls()
gvtrack.clear()
gvtrack.ls()


misha documentation built on Aug. 24, 2026, 5:14 p.m.