Downloads multiple files from FTP server
Details
This function downloads files from FTP server given by 'url'. The address in 'url' can contain wildcards to download more than one file at once. Files are downloaded to a directory given by 'path' argument. If 'path' is 'NULL', file are downloaded into 'GROOT/downloads'.
Examples
gdb.init_examples()
# \donttest{
outdir <- tempdir()
gwget("ftp://hgdownload.soe.ucsc.edu/goldenPath/hg19/chromosomes/md5sum.txt", path = outdir)
#> Downloading ftp://hgdownload.soe.ucsc.edu/goldenPath/hg19/chromosomes/md5sum.txt
# }