Returns a list of the working database and all loaded datasets.
gdataset.ls(dataframe = FALSE)Character vector of paths or data frame with detailed information
dataset_path <- gdataset.example_path()
gdataset.load(dataset_path)
gdataset.ls()
#> [1] "/tmp/RtmpGiBn7o/trackdb/test"
#> [2] "/tmp/RtmpGiBn7o/misha_dataset_1bfb24c13d41"
gdataset.unload(dataset_path)