View source: R/intervals-operations.R
| gintervals.2d.union | R Documentation |
Unites two sets of two-dimensional intervals.
gintervals.2d.union(intervals1 = NULL, intervals2 = NULL)
intervals1, intervals2 |
two-dimensional intervals (a data frame or the name of an intervals set) |
Concatenates 'intervals1' and 'intervals2' and returns the combined set
sorted as by gintervals.2d. Overlapping rectangles are not
merged: because the union of two rectangles is not generally a rectangle,
the result is simply the combined set (unlike the 1D
gintervals.union).
A data frame with the six 2D interval columns, sorted as by
gintervals.2d.
gintervals.2d, gintervals.2d.intersect,
gintervals.union
gdb.init_examples()
a <- gintervals.2d("chr1", 0, 1000, "chr2", 0, 1000)
b <- gintervals.2d("chr1", 500, 1500, "chr2", 500, 1500)
gintervals.2d.union(a, b)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.