View source: R/intervals-attr.R
| gintervals.attr.export | R Documentation |
Returns interval set attributes values.
gintervals.attr.export(intervals.set = NULL, attrs = NULL)
intervals.set |
a vector of interval set names or 'NULL' |
attrs |
a vector of attribute names or 'NULL' |
This function returns a data frame that contains interval set attribute values. Column names of the data frame consist of the attribute names, row names contain the interval set names.
The list of required interval sets is specified by 'intervals.set' argument. If 'intervals.set' is 'NULL' the attribute values of all existing interval sets are returned.
Likewise the list of required attributes is controlled by 'attrs' argument. If 'attrs' is 'NULL' all attribute values of the specified interval sets are returned. The columns are sorted then by "popularity" of an attribute, i.e. the number of interval sets containing this attribute. This sorting is not applied if 'attrs' is not 'NULL'.
Empty character string in a table cell marks a non-existing attribute.
A data frame containing interval set attribute values.
gintervals.attr.import,
gintervals.attr.get, gintervals.attr.set
gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value1")
gintervals.attr.export()
gintervals.attr.export(intervals.set = "annotations")
gintervals.attr.export(attrs = "test_attr")
gintervals.attr.set("annotations", "test_attr", "")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.