View source: R/intervals-attr.R
| gintervals.attr.get | R Documentation |
Returns value of an interval set attribute.
gintervals.attr.get(intervals.set = NULL, attr = NULL)
intervals.set |
interval set name |
attr |
attribute name |
This function returns the value of an interval set attribute. If the attribute does not exist an empty string is returned.
Interval set attribute value (character string).
gintervals.attr.set,
gintervals.attr.export, gintervals.attr.import
gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
gintervals.attr.set("annotations", "test_attr", "")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.