Returns value of an interval set attribute.
Details
This function returns the value of an interval set attribute. If the attribute does not exist an empty string is returned.
Examples
gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
#> [1] "value"
gintervals.attr.set("annotations", "test_attr", "")