Returns value of an interval set attribute.
gintervals.attr.get(intervals.set = NULL, attr = NULL)Interval set attribute value (character string).
This function returns the value of an interval set attribute. If the attribute does not exist an empty string is returned.
gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
#> [1] "value"
gintervals.attr.set("annotations", "test_attr", "")