Learn R Programming

misha (version 5.11.23)

gintervals.attr.get: Returns value of an interval set attribute

Description

Returns value of an interval set attribute.

Usage

gintervals.attr.get(intervals.set = NULL, attr = NULL)

Value

Interval set attribute value (character string).

Arguments

intervals.set

interval set name

attr

attribute name

Details

This function returns the value of an interval set attribute. If the attribute does not exist an empty string is returned.

See Also

gintervals.attr.set, gintervals.attr.export, gintervals.attr.import

Examples

Run this code
# \dontshow{
options(gmax.processes = 2)
# }

gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
gintervals.attr.set("annotations", "test_attr", "")

Run the code above in your browser using DataLab