View source: R/intervals-attr.R
| gintervals.attr.set | R Documentation |
Assigns value to an interval set attribute.
gintervals.attr.set(intervals.set = NULL, attr = NULL, value = NULL)
intervals.set |
interval set name |
attr |
attribute name |
value |
value (character string) |
This function creates an interval set attribute and assigns 'value' to it. If the attribute already exists its value is overwritten.
If 'value' is an empty string the attribute is removed.
None.
gintervals.attr.get,
gintervals.attr.export, gintervals.attr.import
gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
gintervals.attr.set("annotations", "test_attr", "")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.