Learn R Programming

misha (version 5.11.23)

gintervals.attr.set: Assigns value to an interval set attribute

Description

Assigns value to an interval set attribute.

Usage

gintervals.attr.set(intervals.set = NULL, attr = NULL, value = NULL)

Value

None.

Arguments

intervals.set

interval set name

attr

attribute name

value

value (character string)

Details

This function creates an interval set attribute and assigns 'value' to it. If the attribute already exists its value is overwritten.

If 'value' is an empty string the attribute is removed.

See Also

gintervals.attr.get, gintervals.attr.export, gintervals.attr.import

Examples

Run this code
# \dontshow{
options(gmax.processes = 2)
# }

gdb.init_examples()
gintervals.attr.set("annotations", "test_attr", "value")
gintervals.attr.get("annotations", "test_attr")
gintervals.attr.set("annotations", "test_attr", "")

Run the code above in your browser using DataLab