View source: R/compute-utils.R
| gsample | R Documentation |
Returns a sample of the specified size from the values of track expression.
gsample(expr = NULL, n = NULL, intervals = NULL, iterator = NULL, band = NULL)
expr |
track expression |
n |
a number of items to choose |
intervals |
genomic scope for which the function is applied |
iterator |
track expression iterator. If 'NULL' iterator is determined implicitly based on track expression. |
band |
track expression band. If 'NULL' no band is used. |
This function returns a sample of the specified size from the values of
track expression. If 'n' is less than the total number of values, the data
is randomly sampled. Call set.seed() before this function to make
the sample reproducible.
If 'n' is higher than the total number of values, all values are returned (yet reshuffled).
An array that represent quantiles.
gextract
gdb.init_examples()
gsample("sparse_track", 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.