Saves a trained Markov model in the cross-platform .gsm format, which consists of a metadata YAML file and raw binary arrays for counts and CDFs. The .gsm format can be stored as a directory (default) or a ZIP archive.
gsynth.save(model, file, compress = FALSE)A gsynth.model object from gsynth.train
Path to save the model (directory or .zip file)
Logical. If TRUE, save as a ZIP archive. If
FALSE (default), save as a directory.
Invisibly returns the file path.