Learn R Programming

misha (version 5.11.23)

gsynth.save: Save a gsynth.model to disk in .gsm format

Description

Saves a trained Markov model in the cross-platform .gsm format, which consists of a metadata YAML file and raw binary arrays for counts and CDFs. The .gsm format can be stored as a directory (default) or a ZIP archive.

Usage

gsynth.save(model, file, compress = FALSE)

Value

Invisibly returns the file path.

Arguments

model

A gsynth.model object from gsynth.train

file

Path to save the model (directory or .zip file)

compress

Logical. If TRUE, save as a ZIP archive. If FALSE (default), save as a directory.

See Also

gsynth.load, gsynth.train, gsynth.convert