This function creates a new 'Sparse' track with values at given intervals.
'description' is added as a track attribute.
When multiple databases are connected via gsetroot, the track
is created in the current working directory (.misha$GWD), which defaults to the
last connected database. Use gdir.cd with an absolute path to
change where new tracks are created.
values is matched to intervals row by row, in the order the
intervals are passed; intervals need not be sorted. Note however that
gintervals returns its result sorted in the canonical
chromosome order, so building intervals with gintervals() while
keeping values in the original order will bind values to the wrong
intervals. Keep the values in a value column of the intervals data
frame and omit values to make such a mismatch impossible.