| gvtrack.clear | R Documentation |
Deletes all virtual tracks of the current working directory.
gvtrack.clear()
This function removes every virtual track defined for the current working
directory in one call. After it returns gvtrack.ls reports no
virtual tracks. It is a convenient way to reset virtual-track state between
analyses. Use gvtrack.rm to remove a single virtual track.
None.
gvtrack.rm, gvtrack.ls,
gvtrack.create
gdb.init_examples()
gvtrack.create("vtrack1", "dense_track", "max")
gvtrack.create("vtrack2", "dense_track", "avg")
gvtrack.ls()
gvtrack.clear()
gvtrack.ls()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.